@@ -53,6 +53,10 @@ def main_options(parser):
         group='progressOps',
         help='do not display any progress at all.')
 
+    # parser.add_argument('multiOps', nargs=0, action='grouping')
+    # parser.add_argument('--multi_processing', action='store_true', group='multiOps',
+    #     help='enable video rendering multi-processing.')
+
     parser.add_argument('metadataOps', nargs=0, action='grouping')
     parser.add_argument('--force_fps_to', type=float, group='metadataOps',
         help='manually set the fps value for the input video if detection fails.')
@@ -188,6 +192,12 @@ def main_options(parser):
     parser.add_argument('--export_as_clip_sequence', '-excs', action='store_true',
         help='export as multiple numbered media files.')
 
+    parser.add_argument('--temp_dir', default=None,
+        help='set a path to where temporary files are placed.',
+        extra='If not set, tempdir will be set with Python\'s tempfile module\n'
+            'For Windows users, this file will be in the C drive.\n'
+            'The temp file can get quite big if you\'re generating a huge video, so '
+            'make sure your location has enough space.')
     parser.add_argument('--ffmpeg_location', default=None,
         help='set a custom path to the ffmpeg location.',
         extra='This takes precedence over --my_ffmpeg.')
@@ -240,7 +250,7 @@ def main_options(parser):
 
 def get_chunks(inp, speeds, segment, fps, args, log, audio_samples=None, sample_rate=None):
     from auto_editor.cutting import (combine_audio_motion, combine_segment,
-        apply_spacing_rules, apply_mark_as, apply_frame_margin, seconds_to_frames, cook, chunkify)
+        apply_spacing_rules, apply_mark_as, apply_frame_margin, seconds_to_frames, cook)
 
     frame_margin = seconds_to_frames(args.frame_margin, fps)
     min_clip = seconds_to_frames(args.min_clip_length, fps)
@@ -590,8 +600,6 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
 
 
 def main():
-    dir_path = os.path.dirname(os.path.realpath(__file__))
-
     parser = vanparse.ArgumentParser('Auto-Editor', auto_editor.version,
         description='\nAuto-Editor is an automatic video/audio creator and editor. '\
             'By default, it will detect silence and create a new video with those '\
@@ -601,7 +609,7 @@ def main():
             'loudness and video motion to judge making cuts.\nRun:\n    auto-editor '\
             '--help\n\nTo get the list of options.\n')
 
-    subcommands = ['create', 'test', 'info', 'levels', 'grep']
+    subcommands = ['create', 'test', 'info', 'levels', 'grep', 'subdump']
 
     if(len(sys.argv) > 1 and sys.argv[1] in subcommands):
         obj = __import__('auto_editor.subcommands.{}'.format(sys.argv[1]),
@@ -620,34 +628,39 @@ def main():
 
     is64bit = '64-bit' if sys.maxsize > 2**32 else '32-bit'
 
+    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, args.show_ffmpeg_debug)
+
     if(args.debug and args.input == []):
         import platform
-        log = Log()
-        ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg,
-            args.show_ffmpeg_debug, log)
+
+        dirpath = os.path.dirname(os.path.realpath(__file__))
 
         print('Python Version: {} {}'.format(platform.python_version(), is64bit))
         print('Platform: {} {}'.format(platform.system(), platform.release()))
-        print('Config File path: {}'.format(os.path.join(dir_path, 'config.txt')))
+        print('Config File path: {}'.format(os.path.join(dirpath, 'config.txt')))
         print('FFmpeg path: {}'.format(ffmpeg.getPath()))
         print('FFmpeg version: {}'.format(ffmpeg.version()))
         print('Auto-Editor version {}'.format(auto_editor.version))
         sys.exit()
 
     if(is64bit == '32-bit'):
-        log.warning('You have the 32-bit version of Python, which may lead to '\
+        Log().warning('You have the 32-bit version of Python, which may lead to '
             'memory crashes.')
 
     if(args.version):
         print('Auto-Editor version {}'.format(auto_editor.version))
         sys.exit()
 
-    TEMP = tempfile.mkdtemp()
+    if(args.temp_dir is None):
+        TEMP = tempfile.mkdtemp()
+    else:
+        TEMP = args.temp_dir
+        if(os.path.isfile(TEMP)):
+            Log().error('Temp directory cannot be an already existing file.')
+        if(not os.path.isdir(TEMP)):
+            os.mkdir(TEMP)
+
     log = Log(args.debug, args.quiet, temp=TEMP)
-
-    ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg,
-        args.show_ffmpeg_debug, log)
-
     log.debug('Temp Directory: {}'.format(TEMP))
 
     if(args.input == []):
