@@ -2,6 +2,9 @@
 
 from __future__ import print_function
 
+import sys
+import os.path
+
 def info_options(parser):
     parser.add_argument('--include_vfr', '--has_vfr', action='store_true',
         help='skip information that is very slow to get.')
@@ -15,9 +18,7 @@ def info_options(parser):
         help='the path to a file you want inspected.')
     return parser
 
-def main(sys_args=None):
-    import os
-    import sys
+def main(sys_args=sys.argv[1:]):
 
     import auto_editor
     import auto_editor.vanparse as vanparse
@@ -31,14 +32,10 @@ def main(sys_args=None):
         description='Get basic information about media files.')
     parser = info_options(parser)
 
-    if(sys_args is None):
-        sys_args = sys.args[1:]
-
     log = Log()
     args = parser.parse_args(sys_args, log, 'info')
 
-    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
-    ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg, False, log)
+    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
 
     def aspect_str(w, h):
         w, h = aspect_ratio(int(w), int(h))
