@@ -2,6 +2,8 @@
 
 from __future__ import print_function
 
+import sys
+
 def levels_options(parser):
     parser.add_argument('--output_file', '--output', '-o', type=str,
         default='data.txt')
@@ -17,9 +19,8 @@ def levels_options(parser):
         help='the template')
     return parser
 
-def main(sys_args=None):
+def main(sys_args=sys.argv[1:]):
     import os
-    import sys
     import math
     import tempfile
 
@@ -36,16 +37,12 @@ def main(sys_args=None):
         description='Get loudness of audio over time.')
     parser = levels_options(parser)
 
-    if(sys_args is None):
-        sys_args = sys.args[1:]
-
     temp = tempfile.mkdtemp()
     log = Log(temp=temp)
 
     args = parser.parse_args(sys_args, log, 'levels')
 
-    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
-    ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg, False, log)
+    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
 
     inp = ffmpeg.file_info(args.input[0])
 
